<?php
/**
 * CardBatchController.php
 * User: ZhouBenXu
 * Date: 2024/6/27
 * Time: 上午9:36
 * Notes: 卡批次管理
 */

namespace app\admin\controller\card;


use support\Request;
use support\Response;
use app\admin\validate\card\CardBatchValidate;
use app\admin\service\card\CardBatchService;
use Tinywan\Jwt\JwtToken;

class CardBatchController
{

    /**
     * Notes: 添加卡批次
     * User: ZhouBenXu
     * DateTime: 2024/6/27 上午9:44
     */
    public function insert(Request $request)
    {
        $params = $request->post();
        $params['join_card_batch_user_id'] = JwtToken::getCurrentId();
        // 验证器
        $validate = new CardBatchValidate();
        if (!$validate->scene('add')->check($params)) {
            return json_fail($validate->getError());
        }
        return CardBatchService::insert($params);
    }

    /**
     * Notes: 修改卡批次 仅修改名称 状态 有效期
     * User: ZhouBenXu
     * DateTime: 2024/6/27 上午9:44
     */
    public function save(Request $request)
    {
        $params = $request->post();
        $params['join_card_batch_user_id'] = JwtToken::getCurrentId();
        // 验证器
        $validate = new CardBatchValidate();
        if (!$validate->scene('save')->check($params)) {
            return json_fail($validate->getError());
        }

        // 校验有效期 0 永久 1增加 2 减少
        return CardBatchService::save($params);
    }


    /**
     * Notes: 删除 支持批量
     * User: ZhouBenXu
     * DateTime: 2024/6/27 下午5:41
     * @param Request $request
     * @return Response
     */
    public function delete(Request $request)
    {
        $card_batch_ids = $request->post('card_batch_ids');
        return CardBatchService::delete($card_batch_ids);
    }


}